@@ -27,9 +27,9 @@ from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_utils import excutils
 
+from ironic_lib.common.i18n import _LE
+from ironic_lib.common.i18n import _LW
 from ironic_lib import exception
-from ironic_lib.openstack.common._i18n import _LE
-from ironic_lib.openstack.common._i18n import _LW
 
 utils_opts = [
     cfg.StrOpt('rootwrap_config',
@@ -146,7 +146,7 @@ def dd(src, dst, *args):
     """
     LOG.debug("Starting dd process.")
     execute('dd', 'if=%s' % src, 'of=%s' % dst, *args,
-            run_as_root=True, check_exit_code=[0])
+            use_standard_locale=True, run_as_root=True, check_exit_code=[0])
 
 
 def is_http_url(url):
